@@ -141,5 +141,7 @@ class PVML(DataSourceOutputML):
     def normalize(self):
         """Normalize the gsp data"""
         if not self.normalized:
-            self.pv_yield = self.pv_yield - self.pv_capacity
+            # Expand capacity to the same timesteps for broadcasting
+            capacity = np.expand_dims(self.pv_capacity, axis=1)
+            self.pv_yield = self.pv_yield - capacity
             self.normalized = True
